==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/LastMonthExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { LastMonthExpressionDescription } from "./LastMonthExpressionDescription";
/**
 * @hidden
 */
export let LastMonthExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class LastMonthExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (LastMonthExpressionDescriptionMetadata.a == null) {
                LastMonthExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LastMonthExpressionDescriptionMetadata.c(LastMonthExpressionDescriptionMetadata.a);
            }
            if (a.j(LastMonthExpressionDescriptionMetadata.a)) {
                return;
            }
            a.y(LastMonthExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            LastMonthExpressionDescriptionMetadata.b(a);
            a.aa("LastMonthExpression", () => new LastMonthExpressionDescription());
            a.z("LastMonthExpression", LastMonthExpressionDescriptionMetadata.a);
        }
    }
    LastMonthExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(LastMonthExpressionDescriptionMetadata, 'LastMonthExpressionDescriptionMetadata');
    LastMonthExpressionDescriptionMetadata.a = null;
    return LastMonthExpressionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/LastMonthExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { LastMonthExpressionDescription } from "./LastMonthExpressionDescription";
/**
 * @hidden
 */
export let LastMonthExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class LastMonthExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (LastMonthExpressionDescriptionMetadata.a == null) {
                LastMonthExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LastMonthExpressionDescriptionMetadata.c(LastMonthExpressionDescriptionMetadata.a);
            }
            if (a.k(LastMonthExpressionDescriptionMetadata.a)) {
                return;
            }
            a.aa(LastMonthExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            LastMonthExpressionDescriptionMetadata.b(a);
            a.ac("LastMonthExpression", () => new LastMonthExpressionDescription());
            a.ab("LastMonthExpression", LastMonthExpressionDescriptionMetadata.a);
        }
    }
    LastMonthExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(LastMonthExpressionDescriptionMetadata, 'LastMonthExpressionDescriptionMetadata');
    LastMonthExpressionDescriptionMetadata.a = null;
    return LastMonthExpressionDescriptionMetadata;
})();
